@@ -13,7 +13,7 @@ class AuthConfig:
         if platform.system() == "Windows":
             self.folder= self.home_directory + "\.E2E_CLI"
             self.file= self.home_directory + "\.E2E_CLI\config.json"
-        elif platform.system() == "Linux" or platform.system() == "Mac":
+        elif platform.system() == "Linux" or platform.system() == "Darwin":
             self.folder= self.home_directory + "/.E2E_CLI"
             self.file= self.home_directory + "/.E2E_CLI/config.json"
 
@@ -21,9 +21,6 @@ class AuthConfig:
     def windows_hider(self):
         os.system("attrib +h " + self.folder)
 
-    def macOS_hider(self):
-        os.system("chflags hidden" + self.folder)
-
     def windows_file_check(self):
         if not os.path.isdir(self.folder):
             return -1
@@ -34,17 +31,7 @@ class AuthConfig:
             self.windows_hider()
             return 1
 
-    def macOS_file_check(self):
-        if not os.path.isdir(self.folder):
-            return -1
-        elif not os.path.isfile(self.file):
-            self.macOS_hider()
-            return 0
-        else:
-            self.macOS_hider()
-            return 1
-
-    def linux_file_check(self):
+    def linux_mac_file_check(self):
         if not os.path.isdir(self.folder):
             return -1
         elif not os.path.isfile(self.file):
@@ -55,10 +42,8 @@ class AuthConfig:
     def check_if_file_exist(self):
         if platform.system() == "Windows":
             return self.windows_file_check()
-        elif platform.system() == "Linux":
-            return self.linux_file_check()
-        elif platform.system() == "Mac":
-            return self.macOS_file_check()
+        elif platform.system() == "Linux" or platform.system() == "Darwin":
+            return self.linux_mac_file_check()
 
     def add_json_to_file(self):
         api_access_credentials_object = {"api_key": self.kwargs["api_key"],
